@@ -62,7 +62,6 @@ struct _HdyStyleManager
   HdyColorScheme color_scheme;
   gboolean dark;
 
-  GtkCssProvider *animations_provider;
   guint animation_timeout_id;
 };
 
@@ -216,6 +215,14 @@ get_system_theme_name (void)
   return g_value_dup_string (&value);
 }
 
+static gboolean
+check_current_theme_exists (gboolean dark)
+{
+  g_autofree gchar *theme_name = get_system_theme_name ();
+
+  return check_theme_exists (theme_name, dark ? "dark" : NULL);
+}
+
 static void
 warn_prefer_dark_theme (HdyStyleManager *self)
 {
@@ -257,8 +264,8 @@ enable_animations_cb (HdyStyleManager *self)
 {
   GdkScreen *screen = gdk_display_get_default_screen (self->display);
 
-  gtk_style_context_remove_provider_for_screen (screen,
-                                                GTK_STYLE_PROVIDER (self->animations_provider));
+  gtk_settings_reset_property (gtk_settings_get_for_screen (screen),
+                               "gtk-enable-animations");
 
   self->animation_timeout_id = 0;
 
@@ -288,6 +295,7 @@ update_stylesheet (HdyStyleManager *self)
 {
   GdkScreen *screen;
   GtkSettings *gtk_settings;
+  gboolean enable_animations;
 
   if (!self->display)
     return;
@@ -302,47 +310,42 @@ update_stylesheet (HdyStyleManager *self)
                                    G_CALLBACK (update_stylesheet),
                                    self);
 
-  if (self->animation_timeout_id)
+  if (self->animation_timeout_id) {
     g_clear_handle_id (&self->animation_timeout_id, g_source_remove);
+    enable_animations = TRUE;
+  } else {
+    g_object_get (gtk_settings,
+                  "gtk-enable-animations", &enable_animations,
+                  NULL);
+  }
 
-  gtk_style_context_add_provider_for_screen (screen,
-                                             GTK_STYLE_PROVIDER (self->animations_provider),
-                                             10000);
+  if (enable_animations)
+    g_object_set (gtk_settings, "gtk-enable-animations", FALSE, NULL);
 
   g_object_set (gtk_settings,
                 "gtk-application-prefer-dark-theme", self->dark,
                 NULL);
 
-  if (hdy_settings_get_high_contrast (self->settings)) {
+  if (hdy_settings_get_high_contrast (self->settings))
     g_object_set (gtk_settings,
                   "gtk-theme-name",
                   self->dark ? "HighContrastInverse" : "HighContrast",
                   NULL);
-  } else {
-    g_autofree gchar *theme_name = get_system_theme_name ();
-    gboolean override_theme = FALSE;
-
-    if (g_str_has_suffix (theme_name, "-dark")) {
-      theme_name[strlen (theme_name) - 5] = '\0';
-      override_theme = TRUE;
-    }
-
-    if (!check_theme_exists (theme_name, self->dark ? "dark" : NULL))
-      g_object_set (gtk_settings, "gtk-theme-name", "Adwaita", NULL);
-    else if (override_theme)
-      g_object_set (gtk_settings, "gtk-theme-name", theme_name, NULL);
-    else
-      gtk_settings_reset_property (gtk_settings, "gtk-theme-name");
-  }
+  else if (check_current_theme_exists (self->dark))
+    gtk_settings_reset_property (gtk_settings, "gtk-theme-name");
+  else
+    g_object_set (gtk_settings, "gtk-theme-name", "Adwaita", NULL);
 
   g_signal_handlers_unblock_by_func (gtk_settings,
                                      G_CALLBACK (warn_prefer_dark_theme),
                                      self);
 
-  self->animation_timeout_id =
-    g_timeout_add (SWITCH_DURATION,
-                   G_SOURCE_FUNC (enable_animations_cb),
-                   self);
+  if (enable_animations) {
+    self->animation_timeout_id =
+      g_timeout_add (SWITCH_DURATION,
+                     G_SOURCE_FUNC (enable_animations_cb),
+                     self);
+  }
 
   g_idle_add (G_SOURCE_FUNC (unblock_theme_name_changed_cb), self);
 }
@@ -422,12 +425,6 @@ hdy_style_manager_constructed (GObject *object)
                              G_CALLBACK (update_stylesheet),
                              self,
                              G_CONNECT_SWAPPED);
-
-    self->animations_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (self->animations_provider,
-                                     "* { transition: none; }",
-                                     -1,
-                                     NULL);
   }
 
   self->settings = hdy_settings_get_default ();
@@ -453,7 +450,6 @@ hdy_style_manager_dispose (GObject *object)
   HdyStyleManager *self = HDY_STYLE_MANAGER (object);
 
   g_clear_handle_id (&self->animation_timeout_id, g_source_remove);
-  g_clear_object (&self->animations_provider);
 
   G_OBJECT_CLASS (hdy_style_manager_parent_class)->dispose (object);
 }
